summaryrefslogtreecommitdiff
path: root/numpy/lib/function_base.py
diff options
context:
space:
mode:
Diffstat (limited to 'numpy/lib/function_base.py')
-rw-r--r--numpy/lib/function_base.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/numpy/lib/function_base.py b/numpy/lib/function_base.py
index 3826715e1..26d25cd6d 100644
--- a/numpy/lib/function_base.py
+++ b/numpy/lib/function_base.py
@@ -547,8 +547,7 @@ def average(a, axis=None, weights=None, returned=False):
def asarray_chkfinite(a, dtype=None, order=None):
- """
- Convert the input to an array, checking for NaNs or Infs.
+ """Convert the input to an array, checking for NaNs or Infs.
Parameters
----------
@@ -559,8 +558,9 @@ def asarray_chkfinite(a, dtype=None, order=None):
dtype : data-type, optional
By default, the data-type is inferred from the input data.
order : {'C', 'F'}, optional
- Whether to use row-major ('C') or column-major ('FORTRAN') memory
- representation. Defaults to 'C'.
+ Whether to use row-major (C-style) or
+ column-major (Fortran-style) memory representation.
+ Defaults to 'C'.
Returns
-------